import javax.swing.*;
import java.awt.BorderLayout;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;

/**
 * Set up the window and show two buttons, a text field, and a label.
 * The size of the window is determined from the size of the four components.
 * The two buttons are arranged side by side in the NORTH section, by using a JPanel.
 * One button copies the contents of the text field to the label; the other clears the text field.
 * This is a more reasonable application of anonymous inner classes.
 * @version 16, 3 Feb 2005.
 **/
public class SetUpOperation implements Runnable
{
    JLabel centerText = new JLabel ("some text in the center");
    JTextField input = new JTextField ("Please type something here.");

    public void run () {
        // Make sure we have nice window decorations.
        JFrame.setDefaultLookAndFeelDecorated(true);
        
        // Create the window and set its size.
        JFrame frame = new JFrame ("My example program");
        
        // Make sure the program exits when the window is closed.
        frame.setDefaultCloseOperation (JFrame.EXIT_ON_CLOSE);
        
        // Add something to the window.
        JButton copyButton = new JButton ("copy");
        JButton clearButton = new JButton ("clear");
        JPanel buttons = new JPanel ();
        buttons.add (copyButton);
        buttons.add (clearButton);
        frame.getContentPane().add(this.centerText, BorderLayout.CENTER);
        frame.getContentPane().add(buttons, BorderLayout.NORTH);
        frame.getContentPane().add(this.input, BorderLayout.SOUTH);
        
        copyButton.addActionListener (new ActionListener () {
            public void actionPerformed (ActionEvent e) {
                centerText.setText (input.getText());
            }});
        clearButton.addActionListener (new ActionListener () {
            public void actionPerformed (ActionEvent e) {
                centerText.setText ("");
            }});
        
        // Compute the size of the window, just big enough to hold the labels.
        frame.pack();
        
        // Show the window.
        frame.setVisible(true);
    }
}